==> deepin-screenshot_4.0.11.orig.tar.gz: deepin-screenshot-4.0.11/translations/deepin-screenshot_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="618"/>
        <source>select-area</source>
        <translation>вибрати-область</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="951"/>
        <location filename="../mainwindow.cpp" line="953"/>
        <location filename="../mainwindow.cpp" line="1209"/>
        <location filename="../mainwindow.cpp" line="1212"/>
        <location filename="../mainwindow.cpp" line="1225"/>
        <location filename="../mainwindow.cpp" line="1228"/>
        <location filename="../mainwindow.cpp" line="1268"/>
        <location filename="../mainwindow.cpp" line="1271"/>
        <location filename="../mainwindow.cpp" line="1303"/>
        <location filename="../mainwindow.cpp" line="1306"/>
        <source>DeepinScreenshot</source>
        <translation>Знімок екрану Deepin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="970"/>
        <location filename="../mainwindow.cpp" line="1321"/>
        <source>View</source>
        <translation>Переглянути</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="984"/>
        <location filename="../mainwindow.cpp" line="1341"/>
        <source>Picture has been saved to %1</source>
        <translation>Зображення було збережено до %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1233"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1339"/>
        <source>Picture has been saved to clipboard</source>
        <translation>Зображення було збережено до буфера обміну</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="15"/>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="23"/>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="31"/>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="39"/>
        <source>Pencil</source>
        <translation>Олівець</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="47"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="55"/>
        <source>Undo</source>
        <translation>Вернути</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="71"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="74"/>
        <source>Save to desktop</source>
        <translation>Зберегти на робочому столі</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="75"/>
        <source>Autosave</source>
        <translation>Автозбереження</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="76"/>
        <source>Save to specified folder</source>
        <translation>Зберегти до вказаної папки</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="77"/>
        <source>Copy to clipboard</source>
        <translation>Скопіювати до буфера</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="78"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Автоматично зберегти й копіювати в буфер обміну</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="59"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>Знімок екрану Deepin запуститься за %1 секунди</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="10"/>
        <source>Start/Screenshot</source>
        <translation>Старт/Знімок екрана</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="11"/>
        <location filename="../utils/shortcut.cpp" line="22"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="12"/>
        <source>Painting</source>
        <translation>Малювання</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="13"/>
        <source>Size Adjustment</source>
        <translation>Адаптація розміру</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="16"/>
        <source>Quick start</source>
        <translation>Короткий посібник</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="17"/>
        <source>Full screenshot</source>
        <translation>Повний знімок екрана</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="18"/>
        <source>Delay screenshot</source>
        <translation>Скріншот затримки</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="19"/>
        <source>Undo</source>
        <translation>Вернути</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="20"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="23"/>
        <source>Copy to clipboard</source>
        <translation>Скопіювати до буфера</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="26"/>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="27"/>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="28"/>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Pencil</source>
        <translation>Олівець</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="34"/>
        <source>Increase height up</source>
        <translation>Збільшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Increase height down</source>
        <translation>Збільшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Increase width left</source>
        <translation>Збільшити ширину вліво</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Increase width right</source>
        <translation>Збільшити ширину вправо</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Decrease height up</source>
        <translation>Зменшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Decrease height down</source>
        <translation>Зменшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="40"/>
        <source>Decrease width left</source>
        <translation>Зменшити ширину зліва</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Decrease width right</source>
        <translation>Зменшити ширину вправо</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="377"/>
        <source>Save to desktop</source>
        <translation>Зберегти на робочому столі</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="383"/>
        <source>Autosave</source>
        <translation>Автозбереження</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="389"/>
        <source>Save to specified folder</source>
        <translation>Зберегти до вказаної папки</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="395"/>
        <source>Copy to clipboard</source>
        <translation>Скопіювати до буфера</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="400"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Автоматично зберегти й копіювати в буфер обміну</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="405"/>
        <source>Low</source>
        <translation>Низький</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="419"/>
        <source>High</source>
        <translation>Високий</translation>
    </message>
</context>
</TS>

==> deepin-screenshot_4.1.0.orig.tar.gz: deepin-screenshot-4.1.0/translations/deepin-screenshot_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>select-area</source>
        <translation>вибрати-область</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="986"/>
        <location filename="../mainwindow.cpp" line="988"/>
        <location filename="../mainwindow.cpp" line="1246"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="1262"/>
        <location filename="../mainwindow.cpp" line="1265"/>
        <location filename="../mainwindow.cpp" line="1302"/>
        <location filename="../mainwindow.cpp" line="1305"/>
        <location filename="../mainwindow.cpp" line="1337"/>
        <location filename="../mainwindow.cpp" line="1340"/>
        <source>DeepinScreenshot</source>
        <translation>Знімок екрану Deepin</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1004"/>
        <location filename="../mainwindow.cpp" line="1366"/>
        <source>View</source>
        <translation>Переглянути</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1018"/>
        <location filename="../mainwindow.cpp" line="1386"/>
        <source>Picture has been saved to %1</source>
        <translation>Зображення було збережено до %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1270"/>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);; BMP (*.bmp);; PGM (*.pgm);;XBM (*.xbm);;XPM(*.xpm)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1360"/>
        <source>Save failed. Please save it in your home directory.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1384"/>
        <source>Picture has been saved to clipboard</source>
        <translation>Зображення було збережено до буфера обміну</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <location filename="../controller/menucontroller.cpp" line="40"/>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="48"/>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="56"/>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="64"/>
        <source>Pencil</source>
        <translation>Олівець</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="72"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="80"/>
        <source>Undo</source>
        <translation>Вернути</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="96"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="99"/>
        <source>Save to desktop</source>
        <translation>Зберегти на робочому столі</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="100"/>
        <source>Autosave</source>
        <translation>Автозбереження</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="101"/>
        <source>Save to specified folder</source>
        <translation>Зберегти до вказаної папки</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="102"/>
        <source>Copy to clipboard</source>
        <translation>Скопіювати до буфера</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="103"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Автоматично зберегти й копіювати в буфер обміну</translation>
    </message>
    <message>
        <location filename="../controller/menucontroller.cpp" line="124"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <location filename="../screenshot.cpp" line="78"/>
        <source>Deepin Screenshot will start after %1 seconds</source>
        <translation>Знімок екрану Deepin запуститься за %1 секунди</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <location filename="../utils/shortcut.cpp" line="29"/>
        <source>Start/Screenshot</source>
        <translation>Старт/Знімок екрана</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="30"/>
        <location filename="../utils/shortcut.cpp" line="41"/>
        <source>Save</source>
        <translation>Зберегти</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="31"/>
        <source>Painting</source>
        <translation>Малювання</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="32"/>
        <source>Size Adjustment</source>
        <translation>Адаптація розміру</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="35"/>
        <source>Quick start</source>
        <translation>Короткий посібник</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="36"/>
        <source>Full screenshot</source>
        <translation>Повний знімок екрана</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="37"/>
        <source>Delay screenshot</source>
        <translation>Скріншот затримки</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="38"/>
        <source>Undo</source>
        <translation>Вернути</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="39"/>
        <source>Exit</source>
        <translation>Вихід</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="42"/>
        <source>Copy to clipboard</source>
        <translation>Скопіювати до буфера</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="45"/>
        <source>Rectangle</source>
        <translation>Прямокутник</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="46"/>
        <source>Ellipse</source>
        <translation>Еліпс</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="47"/>
        <source>Arrow</source>
        <translation>Стрілка</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="48"/>
        <source>Pencil</source>
        <translation>Олівець</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="49"/>
        <source>Text</source>
        <translation>Текст</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="50"/>
        <source>Color</source>
        <translation>Колір</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="53"/>
        <source>Increase height up</source>
        <translation>Збільшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="54"/>
        <source>Increase height down</source>
        <translation>Збільшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="55"/>
        <source>Increase width left</source>
        <translation>Збільшити ширину вліво</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="56"/>
        <source>Increase width right</source>
        <translation>Збільшити ширину вправо</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="57"/>
        <source>Decrease height up</source>
        <translation>Зменшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="58"/>
        <source>Decrease height down</source>
        <translation>Зменшити висоту</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="59"/>
        <source>Decrease width left</source>
        <translation>Зменшити ширину зліва</translation>
    </message>
    <message>
        <location filename="../utils/shortcut.cpp" line="60"/>
        <source>Decrease width right</source>
        <translation>Зменшити ширину вправо</translation>
    </message>
</context>
<context>
    <name>SubToolBar</name>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="397"/>
        <source>Save to desktop</source>
        <translation>Зберегти на робочому столі</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="403"/>
        <source>Autosave</source>
        <translation>Автозбереження</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="409"/>
        <source>Save to specified folder</source>
        <translation>Зберегти до вказаної папки</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="415"/>
        <source>Copy to clipboard</source>
        <translation>Скопіювати до буфера</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="420"/>
        <source>Autosave and copy to clipboard</source>
        <translation>Автоматично зберегти й копіювати в буфер обміну</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="425"/>
        <source>Low</source>
        <translation>Низький</translation>
    </message>
    <message>
        <location filename="../widgets/subtoolbar.cpp" line="439"/>
        <source>High</source>
        <translation>Високий</translation>
    </message>
</context>
</TS>
